@@ -23,7 +23,12 @@ using System.Linq;
 using System.Threading;
 using System.Collections.Generic;
 
+#if USE_DBUS_SHARP
+using DBus;
+#else
 using NDesk.DBus;
+#endif
+
 using org.freedesktop.DBus;
 
 using Do.Platform;
@@ -69,6 +74,7 @@ namespace Banshee
 
 		static BansheeDBus ()
 		{
+			BusG.Init ();
 			BuildObjectPathsDict ();
 			session_bus = Bus.Session.GetObject<IBus> (SessionBusName, new ObjectPath (object_paths[typeof (IBus)]));
 			session_bus.NameOwnerChanged += HandleNameOwnerChanged;
