@@ -22,7 +22,7 @@ using System.Collections.Generic;
 using System.Linq;
 
 using Gnome.Vfs;
-using Mono.Unix;
+using Mono.Addins;
 
 using Do.Universe;
 using Do.Platform;
@@ -37,11 +37,11 @@ namespace DiskMounter
         }
                 
 		public override string Name {
-			get { return Catalog.GetString ("Open"); }
+			get { return AddinManager.CurrentLocalizer.GetString ("Open"); }
 		}
 		
 		public override string Description {
-			get { return Catalog.GetString ("Open a removable volume"); }
+			get { return AddinManager.CurrentLocalizer.GetString ("Open a removable volume"); }
 		}
 		
 		public override string Icon {
@@ -58,9 +58,9 @@ namespace DiskMounter
 			try {
 				if (!drive.IsMounted)
 					drive.Mount ();
-				Services.Environment.OpenPath (drive.Path);
+				Services.Environment.OpenPath (drive.Uri);
 			} catch (Exception e) {
-				Log.Error ("Error opening {0} - {1}", drive.Path, e.Message);
+				Log.Error ("Error opening {0} - {1}", drive.Uri, e.Message);
 				Log.Debug (e.StackTrace);
 			}
 			yield break;
