@@ -19,7 +19,11 @@
  */
 
 using System;
+#if USE_DBUS_SHARP
+using DBus;
+#else
 using NDesk.DBus;
+#endif
 using org.freedesktop.DBus;
 using System.Collections.Generic;
 using Do.Universe;
