@@ -4,7 +4,7 @@ using System.IO;
 using System.Linq;
 using System.Collections.Generic;
 
-using Mono.Unix;
+using Mono.Addins;
 
 using Do.Platform;
 using Do.Universe;
@@ -13,13 +13,13 @@ namespace Microblogging
 {	
 	public class FriendItem : Item
 	{
-		const string DefaultIcon = "stock_person";
+		const string FallbackIcon = "stock_person";
 
 		string name, photo, status;
 		SortedList<DateTime, MicroblogStatus> statuses;
 		
 		public FriendItem (int id, string name) : 
-			this (id, name, new MicroblogStatus (-1, Catalog.GetString ("No Status"), name, DateTime.MinValue))
+			this (id, name, new MicroblogStatus (-1, AddinManager.CurrentLocalizer.GetString ("No Status"), name, DateTime.MinValue))
 		{
 		}
 		
@@ -46,7 +46,7 @@ namespace Microblogging
 			get {
 				if (!string.IsNullOrEmpty (photo) && File.Exists (photo))
 					return photo;
-				return DefaultIcon;
+				return FallbackIcon;
 			}
 		}
 		
