@@ -28,7 +28,13 @@ namespace Pastebin
 	{
 		bool ShouldAllowAutoRedirect { get; }
 		
+		string Name { get; }
+		
 		string BaseUrl { get; }
+
+		string UserAgent { get; }
+		
+		bool Expect100Continue { get; }
 		
 		NameValueCollection Parameters { get; }
 		
