@@ -41,6 +41,7 @@ namespace Pastebin
 			Name = "paste.pocoo.org";
 			BaseUrl = url_root;
 			ShouldAllowAutoRedirect = false;
+			Expect100Continue = false;
 			
 			Parameters[content_key] = "";
 			Parameters[syntax_key] = "text";
@@ -62,11 +63,9 @@ namespace Pastebin
 		public override string GetPasteUrlFromResponse (HttpWebResponse response)
 		{				
 			string responseText;
-			using (Stream responseStream = response.GetResponseStream ()) {
-				using (StreamReader reader = new StreamReader (responseStream)) {
+			using (Stream responseStream = response.GetResponseStream ())
+				using (StreamReader reader = new StreamReader (responseStream))
 					responseText = reader.ReadToEnd ();
-				}
-			}
 			
 			Regex urlPattern = new Regex ("<a href=\"(.*?)\">"); 
 			Match urlMatch = urlPattern.Match (responseText);
