@@ -50,15 +50,13 @@ namespace Pastebin
 			SupportedLanguages = PopulateTextSyntaxItemsFromXml ("PastebinCA.xml");
 		}
 		
-		public PastebinCA(string content, string syntax)
-			: this()
+		public PastebinCA(string content, string syntax) : this()
 		{
 			Parameters[syntax_key] = syntax;
 			Parameters[content_key] = content;
 		}
 		
-		public PastebinCA(string content)
-			: this()
+		public PastebinCA(string content) : this()
 		{
 			Parameters[content_key] = content;
 		}
@@ -66,20 +64,17 @@ namespace Pastebin
 		public override string GetPasteUrlFromResponse(HttpWebResponse response)
 		{
 			string responseText;
-			using (Stream responseStream = response.GetResponseStream ()) {
-				using (StreamReader reader = new StreamReader (responseStream)) {
+			using (Stream responseStream = response.GetResponseStream ())
+				using (StreamReader reader = new StreamReader (responseStream))
 					responseText = reader.ReadToEnd ();
-				}
-			}
 			
 			string url = String.Empty;
-			if (responseText.Contains ("SUCCESS")) {
+			if (responseText.Contains ("SUCCESS"))
 				url = url_root + "/" + responseText.Split (new string[]{":"}, StringSplitOptions.RemoveEmptyEntries)[1];
-			} else {
+			else
 				Log<PastebinCA>.Debug (responseText);
-			}
 			
 			return url;
 		}
 	}
-}
\ No newline at end of file
+}
