@@ -19,6 +19,7 @@
 //
 
 using System;
+using Mono.Addins;
 
 using Do.Universe;
 
@@ -28,12 +29,18 @@ namespace PidginPlugin
 	class PidginHandleContactDetailItem : Item, IContactDetailItem
 	{
 
-		string proto, handle;
-
-		public PidginHandleContactDetailItem (string proto, string handle)
+		string proto, handle, custom_icon, online;
+		
+		public PidginHandleContactDetailItem (string proto, string handle) : this (proto, handle, Pidgin.GetProtocolIcon (proto))
+		{
+		}
+		
+		public PidginHandleContactDetailItem (string proto, string handle, string custom_icon)
 		{
 			this.proto = proto;
 			this.handle = handle;
+			this.custom_icon = custom_icon;
+			this.online = (Pidgin.BuddyIsOnline (handle)) ? AddinManager.CurrentLocalizer.GetString ("Online") : AddinManager.CurrentLocalizer.GetString ("Offline");
 		}
 
 		public override string Name {
@@ -44,14 +51,14 @@ namespace PidginPlugin
 
 		public override string Description {
 			get {
-				return ReadableProto (proto) + " " + "Handle" ;
+				return string.Format ("{0} {1} ({2})", ReadableProto (proto), AddinManager.CurrentLocalizer.GetString ("Handle"), online);
 			}
 		}
 
 		public override string Icon {
-			get { return Pidgin.GetProtocolIcon (proto); }
+			get { return custom_icon; }
 		}
-
+		
 		public string Key {
 			get { return proto; }
 		}
@@ -60,13 +67,20 @@ namespace PidginPlugin
 			get { return handle; }
 		}
 
+		//valid proto values:
+		//prpl-msn, prpl-msn-1, prpl-<contributor>-proto
 		string ReadableProto (string proto)
 		{
-			switch (proto) {
-			case "prpl-aim":		return "AIM";
-			case "prpl-jabber":	return "Jabber";
-			default:						return proto;
-			}
+			string[] parts = proto.Split ('-');
+			string prplProto;
+			int similarProtos;
+			
+			if (int.TryParse (parts [parts.Length-1], out similarProtos))
+				prplProto = parts[1];
+			else
+				 prplProto = parts[parts.Length-1];
+			
+			return (parts.Length >= 2) ? char.ToUpper (prplProto[0]) + prplProto.Substring(1) : proto; 
 		}
 	}
 }
