@@ -21,7 +21,12 @@ using System;
 using System.Linq;
 using System.Collections.Generic;
 
+#if USE_DBUS_SHARP
+using DBus;
+#else
 using NDesk.DBus;
+#endif
+
 using org.freedesktop.DBus;
 
 using Do.Platform;
