@@ -20,7 +20,12 @@
 using System;
 using System.Collections;
 
+#if USE_DBUS_SHARP
+using DBus;
+#else
 using NDesk.DBus;
+#endif
+
 using org.freedesktop.DBus;
 
 namespace Tomboy
