@@ -1,6 +1,11 @@
 
 using System;
+#if USE_DBUS_SHARP
+using DBus;
+#else
 using NDesk.DBus;
+#endif
+
 using org.freedesktop.DBus;
 
 namespace Tracker.Dbus
