@@ -1,7 +1,12 @@
 
 using System;
 
+#if USE_DBUS_SHARP
+using DBus;
+#else
 using NDesk.DBus;
+#endif
+
 
 using Do.Platform;
 
