@@ -21,27 +21,26 @@
 using System;
 
 using Do.Universe;
-using Mono.Unix;
+using Mono.Addins;
 
 namespace VolumeControl
 {
-	public class VolumeDownItem : Item, IRunnableItem
+	public class VolumeDownItem : AbstractVolumeItem
 	{
 		public override string Name {
-			get { return Catalog.GetString ("Volume Down"); }
+			get { return AddinManager.CurrentLocalizer.GetString ("Volume Down"); }
 		}
 		
 		public override string Description {
-			get { return Catalog.GetString ("Decrease system volume"); }
+			get { return AddinManager.CurrentLocalizer.GetString ("Decrease system volume"); }
 		}
 		
 		public override string Icon {
 			get { return "audio-volume-low"; }
 		}
-		
-		public void Run ()
-		{
-			System.Diagnostics.Process.Start ("amixer set Master 3%- /dev/null");
+
+		protected override string VolumeArgument {
+			get { return "5%-"; }
 		}
 	}
 }
