@@ -21,27 +21,26 @@
 using System;
 
 using Do.Universe;
-using Mono.Unix;
+using Mono.Addins;
 
 namespace VolumeControl
 {
-	public class VolumeMuteItem : Item, IRunnableItem
+	public class VolumeMuteItem : AbstractVolumeItem
 	{
 		public override string Name {
-			get { return Catalog.GetString ("Mute Volume"); }
+			get { return AddinManager.CurrentLocalizer.GetString ("Mute Volume"); }
 		}
 		
 		public override string Description {
-			get { return Catalog.GetString ("Mute system volume"); }
+			get { return AddinManager.CurrentLocalizer.GetString ("Mute system volume"); }
 		}
 		
 		public override string Icon {
 			get { return "audio-volume-muted"; }
 		}
-		
-		public void Run ()
-		{
-			System.Diagnostics.Process.Start ("amixer set Master 0% > /dev/null");
+
+		protected override string VolumeArgument {
+			get { return "0%"; }
 		}
 	}
 }
\ No newline at end of file
