@@ -21,27 +21,26 @@
 using System;
 
 using Do.Universe;
-using Mono.Unix;
+using Mono.Addins;
 
 namespace VolumeControl
 {
-	public class VolumeUpItem : Item, IRunnableItem
+	public class VolumeUpItem : AbstractVolumeItem
 	{
 		public override string Name {
-			get { return Catalog.GetString ("Volume Up"); }
+			get { return AddinManager.CurrentLocalizer.GetString ("Volume Up"); }
 		}
 		
 		public override string Description {
-			get { return Catalog.GetString ("Increase system volume"); }
+			get { return AddinManager.CurrentLocalizer.GetString ("Increase system volume"); }
 		}
 		
 		public override string Icon {
 			get { return "audio-volume-high"; }
 		}
-		
-		public void Run ()
-		{
-			System.Diagnostics.Process.Start ("amixer set Master 3%+ /dev/null");
+
+		protected override string VolumeArgument {
+			get { return "5%+"; }
 		}
 	}
 }
