@@ -20,23 +20,21 @@ using System.Collections.Generic;
 using System.Linq;
 
 using Do.Universe;
-using Do.Interface.Wink;
+using WindowManager.Wink;
 
 using Wnck;
 using Mono.Addins;
 
 namespace WindowManager
 {
-	
-	
 	public class WindowMaximizeAction : WindowActionAction
 	{
 		public override string Name {
-			get { return AddinManager.CurrentLocalizer.GetString ("Maximize"); }
+			get { return AddinManager.CurrentLocalizer.GetString ("(Un)Maximize"); }
 		}
 		
 		public override string Description {
-			get { return AddinManager.CurrentLocalizer.GetString ("Make a window consume the whole screen"); }
+			get { return AddinManager.CurrentLocalizer.GetString ("Make a window consume the whole screen or revert to its normal size"); }
 		}
 
 		public override string Icon {
